==> home-library-jcr-1.5.0-20141030.014425-79-sources.jar: org/gcube/common/homelibrary/jcr/workspace/JCRWorkspaceFolder.java <==
package org.gcube.common.homelibrary.jcr.workspace;

import java.util.List;

import javax.jcr.Node;
import javax.jcr.RepositoryException;

import org.gcube.common.homelibrary.home.exceptions.InternalErrorException;
import org.gcube.common.homelibrary.home.workspace.WorkspaceFolder;
import org.gcube.common.homelibrary.home.workspace.WorkspaceItemType;
import org.gcube.common.homelibrary.home.workspace.WorkspaceSharedFolder;
import org.gcube.common.homelibrary.home.workspace.accessmanager.ACLType;
import org.gcube.common.homelibrary.home.workspace.exceptions.InsufficientPrivilegesException;
import org.gcube.common.homelibrary.home.workspace.exceptions.ItemNotFoundException;
import org.gcube.common.homelibrary.home.workspace.exceptions.WorkspaceFolderNotFoundException;
import org.gcube.common.homelibrary.home.workspace.exceptions.WrongDestinationException;
import org.gcube.common.homelibrary.jcr.workspace.accessmanager.JCRAccessManager;


public class JCRWorkspaceFolder extends JCRAbstractWorkspaceFolder {

		
	public JCRWorkspaceFolder(JCRWorkspace workspace, Node node) throws RepositoryException {		
		super(workspace,node);	
	}
	
	public JCRWorkspaceFolder(JCRWorkspace workspace, Node node,
			String name, String description) throws RepositoryException  {		
		super(workspace,node,name,description);
	}

	@Override
	public WorkspaceItemType getType() {
		return WorkspaceItemType.FOLDER;
	}

	@Override	
	public WorkspaceSharedFolder share(List<String> users) throws InsufficientPrivilegesException,
	WrongDestinationException, InternalErrorException {

		try {
			return workspace.shareFolder(users, getId());
		} catch (ItemNotFoundException e) {
			throw new InternalErrorException(e);
		} catch (WorkspaceFolderNotFoundException e) {
			throw new InternalErrorException(e);
		} catch (InternalErrorException e) {
			throw new InternalErrorException(e);
		}

	}

	@Override
	public void setACL(List<String> users,  ACLType privilege) throws InternalErrorException {

		if (!isShared())
			throw new InternalErrorException("ACL cannot be set if the folder is not shared");

		String absPath = null;
		
		try{
			absPath = getAbsolutePath();
		}catch (Exception e) {
			logger.error("Error retrieving absolute path");
		}

		if (absPath == null)
			throw new InternalErrorException("Absolute path cannot be null setting ACL");
		
		
		boolean flag = false;
		JCRAccessManager accessManager = new JCRAccessManager();


		
		int i = 0;
		while ((flag==false) && (i<3)){
			i++;
			try{
				switch(privilege){

				case NONE:
					flag = accessManager.setAccessDenied(users, absPath);		
					break;
				case READ_ONLY:
					flag = accessManager.setReadOnlyACL(users, absPath);		
					break;
				case WRITE_OWNER:	
					flag = accessManager.setWriteOwnerACL(users, absPath);		
					break;
				case WRITE_ALL:
					flag = accessManager.setWriteAllACL(users, absPath);	
					break;
				case ADMINISTRATOR:
					flag = accessManager.setAdminACL(users, absPath);	
					break;
				default:
					break;
				}

				if (flag==false)
					Thread.sleep(1000);

			}catch (Exception e) {
				logger.error("an error occurred setting ACL on: " + absPath);
			}
		}

		logger.info("Has ACL been modified correctly for users " + users.toString() + "in path " + absPath + "? " + flag);	
	}





}

==> home-library-jcr-1.6.0-20141202.161337-48-sources.jar: org/gcube/common/homelibrary/jcr/workspace/JCRWorkspaceFolder.java <==
package org.gcube.common.homelibrary.jcr.workspace;

import java.io.File;
import java.io.InputStream;
import java.util.List;

import javax.jcr.Node;
import javax.jcr.RepositoryException;

import org.gcube.common.homelibrary.home.exceptions.InternalErrorException;
import org.gcube.common.homelibrary.home.workspace.WorkspaceFolder;
import org.gcube.common.homelibrary.home.workspace.WorkspaceItemType;
import org.gcube.common.homelibrary.home.workspace.WorkspaceSharedFolder;
import org.gcube.common.homelibrary.home.workspace.accessmanager.ACLType;
import org.gcube.common.homelibrary.home.workspace.exceptions.InsufficientPrivilegesException;
import org.gcube.common.homelibrary.home.workspace.exceptions.ItemAlreadyExistException;
import org.gcube.common.homelibrary.home.workspace.exceptions.ItemNotFoundException;
import org.gcube.common.homelibrary.home.workspace.exceptions.WorkspaceFolderNotFoundException;
import org.gcube.common.homelibrary.home.workspace.exceptions.WrongDestinationException;
import org.gcube.common.homelibrary.home.workspace.folder.items.ExternalImage;
import org.gcube.common.homelibrary.jcr.repository.external.GCUBEStorage;
import org.gcube.common.homelibrary.jcr.workspace.accessmanager.JCRAccessManager;


public class JCRWorkspaceFolder extends JCRAbstractWorkspaceFolder {


	public JCRWorkspaceFolder(JCRWorkspace workspace, Node node) throws RepositoryException {		
		super(workspace,node);	
	}

	public JCRWorkspaceFolder(JCRWorkspace workspace, Node node,
			String name, String description) throws RepositoryException  {		
		super(workspace,node,name,description);
	}

	@Override
	public WorkspaceItemType getType() {
		return WorkspaceItemType.FOLDER;
	}

	@Override	
	public WorkspaceSharedFolder share(List<String> users) throws InsufficientPrivilegesException,
	WrongDestinationException, InternalErrorException {

		try {
			return workspace.shareFolder(users, getId());
		} catch (ItemNotFoundException e) {
			throw new InternalErrorException(e);
		} catch (WorkspaceFolderNotFoundException e) {
			throw new InternalErrorException(e);
		} catch (InternalErrorException e) {
			throw new InternalErrorException(e);
		}

	}

	@Override
	public void setACL(List<String> users,  ACLType privilege) throws InternalErrorException {

		if (!isShared())
			throw new InternalErrorException("ACL cannot be set if the folder is not shared");

		String absPath = null;

		try{
			absPath = getAbsolutePath();
		}catch (Exception e) {
			logger.error("Error retrieving absolute path");
		}

		if (absPath == null)
			throw new InternalErrorException("Absolute path cannot be null setting ACL");


		boolean flag = false;
		JCRAccessManager accessManager = new JCRAccessManager();

		int i = 0;
		while ((flag==false) && (i<3)){
			i++;
			try{
				switch(privilege){

				case NONE:
					flag = accessManager.setAccessDenied(users, absPath);		
					break;
				case READ_ONLY:
					flag = accessManager.setReadOnlyACL(users, absPath);		
					break;
				case WRITE_OWNER:	
					flag = accessManager.setWriteOwnerACL(users, absPath);		
					break;
				case WRITE_ALL:
					flag = accessManager.setWriteAllACL(users, absPath);	
					break;
				case ADMINISTRATOR:
					flag = accessManager.setAdminACL(users, absPath);	
					break;
				default:
					break;
				}

				if (flag==false)
					Thread.sleep(1000);

			}catch (Exception e) {
				logger.error("an error occurred setting ACL on: " + absPath);
			}
		}

		logger.info("Has ACL been modified correctly for users " + users.toString() + "in path " + absPath + "? " + flag);	
	}






}
